ReaderConstants class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
directCommunicationCommand
→ List<
int> -
final
-
generalAuthCommand
→ List<
int> -
final
-
loadKeyCommand
→ List<
int> -
final
-
readBinaryCommand
→ List<
int> -
final
-
readIdentifierCommand
→ List<
int> -
final
-
successResponse
→ List<
int> -
final
-
updateBinaryCommand
→ List<
int> -
final