ReadBinaryResult class
Constructors
- ReadBinaryResult.failure(SCardResult scardResult)
-
factory
-
ReadBinaryResult.fromStatus(PcscResult status, bool cardCommandSuccess, List<
int> data) -
factory
Properties
- cardCommandSuccess → bool
-
final
-
data
→ List<
int> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isSuccess → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → PcscResult
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited