ReadNuidResult class

Constructors

ReadNuidResult.failure(PcscResult status)
factory
ReadNuidResult.fromStatus(PcscResult status, List<int> nuid)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isSuccess bool
no setter
nuid List<int>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status PcscResult
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited